@@ -10,16 +10,21 @@
 //
 //
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ggos.h"
 
 using namespace std;
 
 gengetopt_option::gengetopt_option() :
     short_opt(0), long_opt(0), desc(0), type(ARG_NO), flagstat(-1),
-            required(1), required_set(false), var_arg(0), default_string(0),
+            required(1), required_set(false), var_arg(0),
+            default_given(0), default_string(0),
             group_value(0), group_desc(0),
             mode_value(0), mode_desc(0),
-            multiple(false),
+            multiple(false), multiple_min(0), multiple_max(0),
             arg_is_optional(false), hidden(false), type_str(0),
             acceptedvalues(0), section(0), section_desc(0), dependon(0),
             text_before(0), text_after(0), details(0), filename(0), linenum(0) {
